@@ -1,7 +1,10 @@
+from pathlib import Path
 from typing import List, NamedTuple, Optional, Tuple
 
 import _mecab
 
+mecabrc_path = Path(__file__).parent / "mecabrc"
+
 
 class Feature(NamedTuple):
     pos: str
@@ -44,12 +47,20 @@ class MeCabError(Exception):
 
 
 class MeCab:  # APIs are inspried by KoNLPy
-    def __init__(self, dictionary_path: Optional[str] = None):
-        arguments = []
-        if dictionary_path is not None:
-            arguments.append(f"-d {dictionary_path}")
+    def __init__(self, dictionary_directory: Optional[str] = None):
+        if dictionary_directory is None:
+            try:
+                import mecab_ko_dic
+                dictionary_directory = mecab_ko_dic.DICDIR
+            except ImportError:
+                raise RuntimeError("`mecab_ko_dic` not found. Please run `pip install mecab_ko_dic`")
 
-        self.tagger = _mecab.Tagger(" ".join(arguments))
+        arguments = [
+            "--rcfile", str(mecabrc_path),
+            "--dicdir", dictionary_directory,
+        ]
+
+        self.tagger = _mecab.Tagger(arguments)
 
     def parse(self, sentence: str) -> List[Tuple[str, Feature]]:
         lattice = _create_lattice(sentence)
